@@ -55,6 +55,9 @@ SEfromHessian <- function(a, hessian=FALSE, silent=FALSE) {
     if (inherits(mathessianx, "try-error")) {
       if (!silent) warning("Error in estimation of the Nearest Positive Definite Matrix. Calculates the Moore-Penrose generalized inverse. Use result with caution.")
       sigma  <- try(ginv(mathessian), silent=TRUE)
+      if (is.null(colnames(sigma)) | is.null(rownames(sigma))) {
+        colnames(sigma) <- rownames(sigma) <- colnames(mathessian)
+      }
     } else {
       if (!silent) warning("Calculates the Nearest Positive Definite Matrix. Use result with caution.")
       sigma  <- try(solve(mathessianx), silent=TRUE)
@@ -76,105 +79,105 @@ SEfromHessian <- function(a, hessian=FALSE, silent=FALSE) {
       
       # Si j'ai des SE négatif... pas bon signe
       if (any(res<0)) {
-          d <- diag(as.matrix(getFromNamespace("nearPD", ns="Matrix")(sigma)$mat))
-          names(d) <- colnames(mathessian)
-          res <- ifelse(d<0, NA, sqrt(d))
-        }
-        if (any(is.na(res))) {
+        d <- diag(as.matrix(getFromNamespace("nearPD", ns="Matrix")(sigma)$mat))
+        names(d) <- colnames(mathessian)
+        res <- ifelse(d<0, NA, sqrt(d))
+      }
+      if (any(is.na(res))) {
+        
+        
+        a <- sigma
+        
+        n = dim(a)[1];
+        root = matrix(0,n,n);
+        
+        for (i in 1:n){
+          sum = 0;
+          if (i>1){
+            sum = sum(root[i,1:(i-1)]^2);
+          }
           
+          x = a[i,i] - sum;
           
-          a <- sigma
+          if (x<0){
+            x = 0;
+          }
           
-          n = dim(a)[1];
-          root = matrix(0,n,n);
+          root[i,i] = sqrt(x);
           
-          for (i in 1:n){
-            sum = 0;
-            if (i>1){
-              sum = sum(root[i,1:(i-1)]^2);
-            }
-            
-            x = a[i,i] - sum;
-            
-            if (x<0){
-              x = 0;
-            }
-            
-            root[i,i] = sqrt(x);
-            
-            if (i < n){
-              for (j in (i+1):n){
-                
-                if (root[i,i] == 0){
-                  x=0;
-                }
-                else{
-                  sum = 0;
-                  if (i>1) {
-                    sum = root[i,1:(i-1)] %*% t(t(root[j,1:(i-1)]))
-                  }
-                  x = (a[i,j] - sum)/root[i,i];
-                }
-                
-                root[j,i] = x;
+          if (i < n){
+            for (j in (i+1):n){
+              
+              if (root[i,i] == 0){
+                x=0;
               }
+              else{
+                sum = 0;
+                if (i>1) {
+                  sum = root[i,1:(i-1)] %*% t(t(root[j,1:(i-1)]))
+                }
+                x = (a[i,j] - sum)/root[i,i];
+              }
+              
+              root[j,i] = x;
             }
           }
+        }
+        colnames(root) <- rownames(root) <- colnames(mathessian)
+        
+        pseudoV <- root %*% t(root)
+        
+        d <- diag(pseudoV)
+        
+        if (any(d != 0) & all(d >= 0)) {
+          res <- sqrt(d)
+          
+          if (!silent) warning("Estimates using pseudo-variance based on Gill & King (2004)")
+          
+        } else {
+          if (!silent) warning("Approximation of Cholesky matrix based on Rebonato and Jackel (2000)")
+          if (!silent) warning("Estimates using pseudo-variance based on Gill & King (2004)")
+          
+          # The paper by Rebonato and Jackel, “The most general methodology for creating a valid correlation matrix for risk management and option pricing purposes”, Journal of Risk, Vol 2, No 2, 2000, presents a methodology to create a positive definite matrix out of a non-positive definite matrix.
+          # FP Brissette, M Khalili, R Leconte, Journal of Hydrology, 2007, “Efficient stochastic generation of multi-site synthetic precipitation data”
+          # GA Baigorria, JW Jones, Journal of Climate, 2010, “GiST: A stochastic model for generating spatially and temporally correlated daily rainfall data”
+          # M Mhanna and W Bauwens, International Journal of Climatology, 2012, “A stochastic space-time model for the generation of daily rainfall in the Gaza Strip”
+          # fix the correl matrix
+          newMat <- a
+          cholError <- TRUE
+          iter <- 0
+          while (cholError) {
+            
+            iter <- iter + 1
+            # cat("iteration ", iter, "\n")
+            
+            # replace -ve eigen values with small +ve number
+            newEig <- eigen(newMat)
+            newEig2 <- ifelse(newEig$values < 0, 0, newEig$values)
+            
+            # create modified matrix eqn 5 from Brissette et al 2007, inv = transp for
+            # eig vectors
+            newMat <- newEig$vectors %*% diag(newEig2) %*% t(newEig$vectors)
+            
+            # normalize modified matrix eqn 6 from Brissette et al 2007
+            newMat <- newMat/sqrt(diag(newMat) %*% t(diag(newMat)))
+            
+            # try chol again
+            cholStatus <- try(u <- chol(newMat), silent = TRUE)
+            cholError <- ifelse(inherits(cholStatus, "try-error"), TRUE, FALSE)
+          }
+          root <- cholStatus
+          
           colnames(root) <- rownames(root) <- colnames(mathessian)
           
           pseudoV <- root %*% t(root)
           
-          d <- diag(pseudoV)
-          
-          if (any(d != 0) & all(d >= 0)) {
-            res <- sqrt(d)
-            
-            if (!silent) warning("Estimates using pseudo-variance based on Gill & King (2004)")
-            
-          } else {
-            if (!silent) warning("Approximation of Cholesky matrix based on Rebonato and Jackel (2000)")
-            if (!silent) warning("Estimates using pseudo-variance based on Gill & King (2004)")
-            
-            # The paper by Rebonato and Jackel, “The most general methodology for creating a valid correlation matrix for risk management and option pricing purposes”, Journal of Risk, Vol 2, No 2, 2000, presents a methodology to create a positive definite matrix out of a non-positive definite matrix.
-            # FP Brissette, M Khalili, R Leconte, Journal of Hydrology, 2007, “Efficient stochastic generation of multi-site synthetic precipitation data”
-            # GA Baigorria, JW Jones, Journal of Climate, 2010, “GiST: A stochastic model for generating spatially and temporally correlated daily rainfall data”
-            # M Mhanna and W Bauwens, International Journal of Climatology, 2012, “A stochastic space-time model for the generation of daily rainfall in the Gaza Strip”
-            # fix the correl matrix
-            newMat <- a
-            cholError <- TRUE
-            iter <- 0
-            while (cholError) {
-              
-              iter <- iter + 1
-              # cat("iteration ", iter, "\n")
-              
-              # replace -ve eigen values with small +ve number
-              newEig <- eigen(newMat)
-              newEig2 <- ifelse(newEig$values < 0, 0, newEig$values)
-              
-              # create modified matrix eqn 5 from Brissette et al 2007, inv = transp for
-              # eig vectors
-              newMat <- newEig$vectors %*% diag(newEig2) %*% t(newEig$vectors)
-              
-              # normalize modified matrix eqn 6 from Brissette et al 2007
-              newMat <- newMat/sqrt(diag(newMat) %*% t(diag(newMat)))
-              
-              # try chol again
-              cholStatus <- try(u <- chol(newMat), silent = TRUE)
-              cholError <- ifelse(inherits(cholStatus, "try-error"), TRUE, FALSE)
-            }
-            root <- cholStatus
-            
-            colnames(root) <- rownames(root) <- colnames(mathessian)
-            
-            pseudoV <- root %*% t(root)
-            
-            res <- sqrt(diag(pseudoV))
-          }
+          res <- sqrt(diag(pseudoV))
         }
       }
     }
-
+  }
+  
   
   SEInf <- namesp[!namesp %in% names(res)]
   
